#[non_exhaustive]pub enum PolicyEnforcementStatus {
Enforced,
Advisory,
Unsupported,
NotRequested,
Unknown,
}Expand description
Structured enforcement status for a policy dimension.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Enforced
The requested policy was technically enforced by the executor backend.
Advisory
The executor ran without technical enforcement and reported the downgrade.
Unsupported
The executor does not support this policy dimension.
NotRequested
This policy dimension was not requested for the command.
Unknown
The executor could not determine whether enforcement happened.
Implementations
Sourceimpl PolicyEnforcementStatus
impl PolicyEnforcementStatus
Sourcepub fn is_enforced(self) -> bool
pub fn is_enforced(self) -> bool
Returns true when the status is PolicyEnforcementStatus::Enforced.
Sourcepub fn is_advisory(self) -> bool
pub fn is_advisory(self) -> bool
Returns true when the status is PolicyEnforcementStatus::Advisory.